@@ -960,7 +960,7 @@ class PGMAccessor(PgAccessor, MAccessor):
         extent1 = pd.DataFrame({'pg_id': list(self.get_bbox()), 'key': 0})
         extent2 = pd.DataFrame({'key': 0, 'month_id': list(self._obj.month_id.unique())})
         extent3 = extent1.merge(extent2, on='key')[['pg_id','month_id']]
-        #print(extent.head())
+        #print(extent.head())a
         extent = extent3.merge(self._obj, how='left', on=['pg_id','month_id'])
         #print(extent.head())
         if 'pgm_id' in self._obj:
@@ -972,10 +972,15 @@ class PGMAccessor(PgAccessor, MAccessor):
     @staticmethod
     def __db_id(z):
         db_ids = fetch_ids_df('priogrid_month')[['id', 'priogrid_gid', 'month_id']]
+        # These lines are not strictly needed but Pandas is not smart enough to do this on its own.
+        db_ids = db_ids[(db_ids.month_id >= z.month_id.min()) & (db_ids.month_id <= z.month_id.max())]
+        db_ids = db_ids[db_ids.priogrid_gid.isin(set(z.pg_id))]
+
         z['pgm_id'] = z.merge(db_ids,
                               left_on=['pg_id', 'month_id'],
                               right_on=['priogrid_gid', 'month_id'],
                               how='left').id
+
         return z
 
     def db_id(self):
@@ -1108,3 +1113,6 @@ class PGYAccessor(PgAccessor):
         z = z[z.pgy_id.notna()]
         z['pgy_id'] = z.pgy_id.astype('int64')
         return z
+
+
+
